﻿unit UTemplateReplacerForm;

interface

uses
  Winapi.Windows, Winapi.Messages, System.SysUtils, System.Variants, System.Classes, Vcl.Graphics,
  Vcl.Controls, Vcl.Forms, Vcl.Dialogs, Vcl.StdCtrls, Vcl.ExtCtrls, UTemplateReplacer;

type
  TTemplateReplacerForm = class(TForm)
    lbTypes: TListBox;
    txtSource: TMemo;
    Panel1: TPanel;
    btnOk: TButton;
    btnCancel: TButton;
    btnDefault: TButton;
    procedure FormClose(Sender: TObject; var Action: TCloseAction);
    procedure lbTypesClick(Sender: TObject);
    procedure txtSourceChange(Sender: TObject);
    procedure btnDefaultClick(Sender: TObject);
    procedure txtSourceKeyPress(Sender: TObject; var Key: Char);
  private
    FSources: TModuleSources;
    FDefaults: TModuleSources;
    procedure Initialize(const ASources, ADefaults: TModuleSources);
  public
    class function Execute(var ASources: TModuleSources; const ADefaults: TModuleSources): Boolean; static;
    property Sources: TModuleSources read FSources;
  end;

implementation

{$R *.dfm}

procedure TTemplateReplacerForm.FormClose(Sender: TObject;
  var Action: TCloseAction);
begin
  Action := caFree;
end;

procedure TTemplateReplacerForm.Initialize(const ASources, ADefaults: TModuleSources);
var
  i: Integer;
begin
  FSources := ASources;
  FDefaults := ADefaults;
  for i := Low(TemplateNames) to High(TemplateNames) do
    lbTypes.Items.Add(TemplateNames[i]);
  lbTypes.ItemIndex := 0;
  lbTypesClick(nil);
end;

procedure TTemplateReplacerForm.lbTypesClick(Sender: TObject);
begin
  if lbTypes.ItemIndex = -1 then Exit;

  txtSource.OnChange := nil;
  txtSource.Text := FSources[lbTypes.ItemIndex];
  txtSource.OnChange := txtSourceChange;
end;

procedure TTemplateReplacerForm.txtSourceChange(Sender: TObject);
begin
  if lbTypes.ItemIndex = -1 then Exit;

  FSources[lbTypes.ItemIndex] := txtSource.Text;
end;

procedure TTemplateReplacerForm.txtSourceKeyPress(Sender: TObject;
  var Key: Char);
begin
  if Key = ^A then
  begin
    txtSource.SelectAll;
    Key := #0;
  end;
end;

procedure TTemplateReplacerForm.btnDefaultClick(Sender: TObject);
begin
  if lbTypes.ItemIndex = -1 then Exit;

  txtSource.Text := FDefaults[lbTypes.ItemIndex];
end;

class function TTemplateReplacerForm.Execute(var ASources: TModuleSources;
  const ADefaults: TModuleSources): Boolean;
var
  form: TTemplateReplacerForm;
begin
  form := TTemplateReplacerForm.Create(nil);
  form.Initialize(ASources, ADefaults);

  Result := form.ShowModal = mrOk;
  if not Result then Exit;

  ASources := form.Sources;
end;

end.
